@@ -55,19 +55,19 @@ public:
 	// Construct with the name of the function and its type.
 	FunctionInfo(const char* name, const char * type, 
           TauGroup_t ProfileGroup = TAU_DEFAULT, 
-	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = false,
+	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = true,
 	  int tid = RtsLayer::myThread());
 	FunctionInfo(const char* name, const string& type, 
 	  TauGroup_t ProfileGroup = TAU_DEFAULT,
-	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = false,
+	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = true,
 	  int tid = RtsLayer::myThread());
 	FunctionInfo(const string& name, const string& type, 
 	  TauGroup_t ProfileGroup = TAU_DEFAULT,
-	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = false,
+	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = true,
 	  int tid = RtsLayer::myThread());
 	FunctionInfo(const string& name, const char * type, 
 	  TauGroup_t ProfileGroup = TAU_DEFAULT,
-	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = false,
+	  const char *ProfileGroupName = "TAU_DEFAULT", bool InitData = true,
 	  int tid = RtsLayer::myThread());
 
 	FunctionInfo(const FunctionInfo& X) ;
@@ -290,9 +290,20 @@ FunctionInfo::GetAlreadyOnStack(int tid)
 	return AlreadyOnStack[tid];
 }
 
+
+void tauCreateFI(FunctionInfo **ptr, const char *name, const char *type, 
+		 TauGroup_t ProfileGroup , const char *ProfileGroupName);
+void tauCreateFI(FunctionInfo **ptr, const char *name, const string& type, 
+		 TauGroup_t ProfileGroup , const char *ProfileGroupName);
+void tauCreateFI(FunctionInfo **ptr, const string& name, const char *type, 
+		 TauGroup_t ProfileGroup , const char *ProfileGroupName);
+void tauCreateFI(FunctionInfo **ptr, const string& name, const string& type, 
+		 TauGroup_t ProfileGroup , const char *ProfileGroupName);
+
+
 #endif /* _FUNCTIONINFO_H_ */
 /***************************************************************************
  * $RCSfile: FunctionInfo.h,v $   $Author: sameer $
- * $Revision: 1.28 $   $Date: 2004/11/02 20:21:00 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.28 2004/11/02 20:21:00 sameer Exp $ 
+ * $Revision: 1.30 $   $Date: 2005/01/05 22:57:10 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.30 2005/01/05 22:57:10 sameer Exp $ 
  ***************************************************************************/
