@@ -36,28 +36,140 @@
 // To ensure that Profiling does not add any runtime overhead when it 
 // is turned off, these macros expand to null.
 //////////////////////////////////////////////////////////////////////
-extern "C" void Tau_start_timer(void * function_info);
+extern "C" void Tau_start_timer(void * function_info, int phase );
 extern "C" void Tau_stop_timer(void * function_info); 
 extern "C" void Tau_create_top_level_timer_if_necessary(void);
 extern "C" void Tau_stop_top_level_timer_if_necessary(void);
 
 #define TAU_TYPE_STRING(profileString, str) static string profileString(str);
+
+#if (TAU_MAX_THREADS == 1)
+// If we're not multi-threaded, just use the non-thread-safe static initializer
+
+#define TAU_PROFILE(name, type, group) \
+        static TauGroup_t tau_gr = group; \
+        static FunctionInfo tauFI(name, type, tau_gr, #group); \
+        Profiler tauFP(&tauFI, tau_gr);
+
+#ifdef TAU_PROFILEPHASE
+#define TAU_PHASE(name, type, group) \
+        static TauGroup_t tau_group = group; \
+        static FunctionInfo tauFInfo(name, type, tau_group, #group); \
+        Profiler tauFProf(&tauFInfo, tau_group); \
+	tauFProf.SetPhase(1);
+#else /* TAU_PROFILEPHASE */
+#define TAU_PHASE TAU_PROFILE
+#endif /* TAU_PROFILEPHASE */
+
+#define TAU_PROFILE_TIMER(var, name, type, group) \
+        static TauGroup_t var##tau_gr = group; \
+        static FunctionInfo *var##fi = new FunctionInfo(name, type, var##tau_gr, #group);
+
+#define TAU_PROFILE_TIMER_DYNAMIC(var, name, type, group) \
+        TauGroup_t var##tau_gr = group; \
+        FunctionInfo *var##fi = new FunctionInfo(name, type, var##tau_gr, #group);
+
+#ifdef TAU_PROFILEPHASE
+#define TAU_PHASE_CREATE_STATIC(var, name, type, group) \
+        static TauGroup_t var##tau_group = group; \
+	static FunctionInfo *var##finfo = new FunctionInfo(name, type, var##tau_group, #group);
+
+#define TAU_PHASE_CREATE_DYNAMIC(var, name, type, group) \
+        TauGroup_t var##tau_group = group; \
+	FunctionInfo *var##finfo = new FunctionInfo(name, type, var##tau_group, #group); 
+
+#define TAU_PHASE_START(var) if (var##tau_group & RtsLayer::TheProfileMask()) \
+                                Tau_start_timer(var##finfo, 1);
+
+#define TAU_PHASE_STOP(var)  if (var##tau_group & RtsLayer::TheProfileMask()) \
+                                Tau_stop_timer(var##finfo);
+#else /* TAU_PROFILEPHASE */
+#define TAU_PHASE_CREATE_STATIC TAU_PROFILE_TIMER
+#define TAU_PHASE_CREATE_DYNAMIC TAU_PROFILE_TIMER_DYNAMIC
+#define TAU_PHASE_START TAU_PROFILE_START
+#define TAU_PHASE_STOP  TAU_PROFILE_STOP
+#endif /* TAU_PROFILEPHASE */
+
+
+
+#else  /* TAU_MAX_THREADS */
+// Multithreaded, we should use thread-safe tauCreateFI to create the FunctionInfo object
+// Note: It's still not absolutely theoretically 100% thread-safe, since the static 
+// initializer is not in a lock, but we don't want to pay that price for every function call 
 #define TAU_PROFILE(name, type, group) \
 	static TauGroup_t tau_gr = group; \
-	static FunctionInfo tauFI(name, type, tau_gr, #group); \
-	Profiler tauFP(&tauFI, tau_gr); 
+	static FunctionInfo *tauFI = NULL; \
+        if (tauFI == 0) \
+          tauCreateFI(&tauFI, name, type, tau_gr, #group); \
+	Profiler tauFP(tauFI, tau_gr); 
+
+#ifdef TAU_PROFILEPHASE
+#define TAU_PHASE(name, type, group) \
+	static TauGroup_t tau_group = group; \
+	static FunctionInfo *tauFInfo = NULL; \
+        tauCreateFI(&tauFInfo, name, type, tau_group, #group); \
+	Profiler tauFProf(tauFInfo, tau_group); \
+	tauFProf.SetPhase(1);
+#else
+#define TAU_PHASE TAU_PROFILE
+#endif /* TAU_PROFILEPHASE */
+
 #define TAU_PROFILE_TIMER(var, name, type, group) \
 	static TauGroup_t var##tau_gr = group; \
-	static FunctionInfo var##fi(name, type, var##tau_gr, #group); 
+	static FunctionInfo *var##fi = NULL; \
+        if (var##fi == 0) \
+          tauCreateFI(&var##fi, name, type, var##tau_gr, #group); 
 
-//	Profiler var(&var##fi, var##tau_gr, true); 
+#define TAU_PROFILE_TIMER_DYNAMIC(var, name, type, group) \
+        TauGroup_t var##tau_gr = group; \
+        FunctionInfo *var##fi = new FunctionInfo(name, type, var##tau_gr, #group);
+
+
+#ifdef TAU_PROFILEPHASE
+#define TAU_PHASE_CREATE_STATIC(var, name, type, group) \
+	static TauGroup_t var##tau_group = group; \
+	static FunctionInfo *var##finfo = NULL; \
+        tauCreateFI(&var##finfo, name, type, var##tau_group, #group); 
+
+#define TAU_PHASE_CREATE_DYNAMIC(var, name, type, group) \
+	TauGroup_t var##tau_group = group; \
+	FunctionInfo *var##finfo = NULL; \
+        tauCreateFI(&var##finfo, name, type, var##tau_group, #group); 
+
+#else
+#define TAU_PHASE_CREATE_STATIC TAU_PROFILE_TIMER
+#define TAU_PHASE_CREATE_DYNAMIC TAU_PROFILE_TIMER_DYNAMIC
+#endif /* TAU_PROFILEPHASE */
 
 // Construct a Profiler obj and a FunctionInfo obj with an extended name
 // e.g., FunctionInfo loop1fi(); Profiler loop1(); 
 #define TAU_PROFILE_START(var) if (var##tau_gr & RtsLayer::TheProfileMask()) \
- 				Tau_start_timer(&var##fi);
+ 				Tau_start_timer(var##fi, 0);
+
+#ifdef TAU_PROFILEPHASE
+#define TAU_PHASE_START(var) if (var##tau_group & RtsLayer::TheProfileMask()) \
+ 				Tau_start_timer(var##finfo, 1);
+#else
+#define TAU_PHASE_START TAU_PROFILE_START
+#endif /* TAU_PROFILEPHASE */
+
+#ifdef TAU_PROFILEPHASE
+#define TAU_PHASE_STOP(var)  if (var##tau_group & RtsLayer::TheProfileMask()) \
+				Tau_stop_timer(var##finfo);
+#else
+#define TAU_PHASE_STOP TAU_PROFILE_STOP
+#endif /* TAU_PROFILEPHASE */
+#endif  /* TAU_MAX_THREADS */
+
+
+
+// Construct a Profiler obj and a FunctionInfo obj with an extended name
+// e.g., FunctionInfo loop1fi(); Profiler loop1();
+#define TAU_PROFILE_START(var) if (var##tau_gr & RtsLayer::TheProfileMask()) \
+                                Tau_start_timer(var##fi, 0);
 #define TAU_PROFILE_STOP(var)  if (var##tau_gr & RtsLayer::TheProfileMask()) \
-				Tau_stop_timer(&var##fi);
+                                Tau_stop_timer(var##fi);
+
 #define TAU_PROFILE_STMT(stmt) stmt;
 #define TAU_PROFILE_EXIT(msg)  Profiler::ProfileExit(msg); 
 #define TAU_PROFILE_INIT(argc, argv) RtsLayer::ProfileInit(argc, argv);
@@ -70,14 +182,46 @@ extern "C" void Tau_stop_top_level_timer_if_necessary(void);
 #define TAU_PROFILE_TIMER_SET_TYPE(t, newname)  t##fi.SetType(newname);
 #define TAU_PROFILE_TIMER_SET_GROUP(t, id) t##fi.SetProfileGroup(id); 
 
-#define TAU_GLOBAL_TIMER(timer, name, type, group) static FunctionInfo timer##fi(name, type, group, #group);
-#define TAU_GLOBAL_TIMER_START(timer) {FunctionInfo *timer##fptr = &timer##fi; \
-        int tau_tid = RtsLayer::myThread(); \
-        Profiler *timer = new Profiler(timer##fptr, timer##fptr != (FunctionInfo *) 0 ? timer##fptr->GetProfileGroup() : TAU_DEFAULT, true, tau_tid); \
-        timer->Start(tau_tid); }
+#define TAU_GLOBAL_TIMER(timer, name, type, group) FunctionInfo& timer (void) { \
+	static FunctionInfo *timer##fi = NULL; \
+        tauCreateFI(&timer##fi, name, type, group, #group); \
+	return *timer##fi; }
+
+#define TAU_GLOBAL_TIMER_START(timer) { static FunctionInfo *timer##fptr= & timer (); \
+	int tau_tid = RtsLayer::myThread(); \
+	Profiler *t = new Profiler (timer##fptr, timer##fptr != (FunctionInfo *) 0 ? timer##fptr->GetProfileGroup() : TAU_DEFAULT, true, tau_tid); \
+        t->Start(tau_tid); }
 
 #define TAU_GLOBAL_TIMER_STOP()  {int tau_threadid = RtsLayer::myThread(); \
-                Profiler::CurrentProfiler[tau_threadid]->Stop(tau_threadid);}
+                Profiler *p = Profiler::CurrentProfiler[tau_threadid]; \
+		p->Stop(tau_threadid); \
+		delete p; \
+		}
+
+#define TAU_GLOBAL_TIMER_EXTERNAL(timer)  extern FunctionInfo& timer(void);
+
+#ifdef TAU_PROFILEPHASE
+#define TAU_GLOBAL_PHASE(timer, name, type, group) FunctionInfo& timer() { \
+	static FunctionInfo *timer##fi = NULL; \
+        tauCreateFI(&timer##fi, name, type, group, #group); \
+	return *timer##fi; }
+
+#define TAU_GLOBAL_PHASE_START(timer) { static FunctionInfo *timer##fptr= & timer (); \
+	int tau_tid = RtsLayer::myThread(); \
+	Profiler *t = new Profiler (timer##fptr, timer##fptr != (FunctionInfo *) 0 ? timer##fptr->GetProfileGroup() : TAU_DEFAULT, true, tau_tid); \
+	t->SetPhase(1); \
+        t->Start(tau_tid); }
+
+#define TAU_GLOBAL_PHASE_STOP(timer) Tau_stop_timer(&timer()); 
+
+#define TAU_GLOBAL_PHASE_EXTERNAL(timer) extern FunctionInfo& timer(void);
+#else /* TAU_PROFILEPHASE */
+#define TAU_GLOBAL_PHASE 	TAU_GLOBAL_TIMER
+#define TAU_GLOBAL_PHASE_START	TAU_GLOBAL_TIMER_START
+#define TAU_GLOBAL_PHASE_STOP(timer)	TAU_GLOBAL_TIMER_STOP()
+#define TAU_GLOBAL_PHASE_EXTERNAL TAU_GLOBAL_TIMER_EXTERNAL
+
+#endif /* TAU_PROFILEPHASE */
 
 /* The above macros are for use with global timers in a multi-threaded application */
 
@@ -211,6 +355,20 @@ extern "C" void Tau_stop_top_level_timer_if_necessary(void);
 #define TAU_TRACK_MUSE_EVENTS()		
 #define TAU_SET_INTERRUPT_INTERVAL(value)
 
+#define TAU_PHASE_CREATE_STATIC(var, name, type, group) 
+#define TAU_PHASE_CREATE_DYNAMIC(var, name, type, group) 
+#define TAU_PHASE_START(var) 
+#define TAU_PHASE_STOP(var) 
+#define TAU_GLOBAL_PHASE(timer, name, type, group) 
+#define TAU_GLOBAL_PHASE_START(timer) 
+#define TAU_GLOBAL_PHASE_STOP(timer)  
+#define TAU_GLOBAL_PHASE_EXTERNAL(timer) 
+#define TAU_GLOBAL_TIMER(timer, name, type, group)
+#define TAU_GLOBAL_TIMER_EXTERNAL(timer)
+#define TAU_GLOBAL_TIMER_START(timer)
+#define TAU_GLOBAL_TIMER_STOP()
+
+
 #define CT(obj)
 
 #endif /* PROFILING_ON */
@@ -235,7 +393,7 @@ extern "C" void Tau_stop_top_level_timer_if_necessary(void);
 
 #endif /* _TAU_API_H_ */
 /***************************************************************************
- * $RCSfile: TauAPI.h,v $   $Author: amorris $
- * $Revision: 1.34 $   $Date: 2004/10/04 23:32:14 $
- * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.34 2004/10/04 23:32:14 amorris Exp $ 
+ * $RCSfile: TauAPI.h,v $   $Author: sameer $
+ * $Revision: 1.49 $   $Date: 2005/01/18 23:57:20 $
+ * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.49 2005/01/18 23:57:20 sameer Exp $ 
  ***************************************************************************/
