@@ -57,7 +57,7 @@ extern "C" {
 #define TAU_PROFILE_CREATE_TIMER(var,name,type,group) Tau_profile_c_timer(&var, name, type, group, #group);
 
 
-#define TAU_PROFILE_START(var) 			Tau_start_timer(var);
+#define TAU_PROFILE_START(var) 			Tau_start_timer(var, 0);
 #define TAU_PROFILE_STOP(var) 			Tau_stop_timer(var);
 #define TAU_PROFILE_STMT(stmt) 			stmt;
 #define TAU_PROFILE_EXIT(msg)  			Tau_exit(msg);
@@ -137,6 +137,38 @@ extern "C" {
 #define TAU_DISABLE_TRACKING_MUSE_EVENTS()	Tau_disable_tracking_muse_events()
 #define TAU_TRACK_MUSE_EVENTS()			Tau_track_muse_events()		
 #define TAU_SET_INTERRUPT_INTERVAL(value)	Tau_set_interrupt_interval(value)
+#define TAU_PHASE_CREATE_STATIC(var, name, type, group) static void *var##finfo = NULL; Tau_profile_c_timer(&var##finfo, name, type, group, #group)
+#define TAU_PHASE_CREATE_DYNAMIC(var, name, type, group) void *var##finfo = NULL; Tau_profile_c_timer(&var##finfo, name, type, group, #group)
+#define TAU_PROFILE_TIMER_DYNAMIC(var, name, type, group) void *var##finfo = NULL; Tau_profile_c_timer(&var##finfo, name, type, group, #group)
+#define TAU_PHASE_START(var) Tau_start_timer(var##finfo, 1)
+#define TAU_PHASE_STOP(var) Tau_stop_timer(var##finfo)
+#define TAU_GLOBAL_PHASE(timer, name, type, group) void * TauGlobalPhase##timer(void) \
+{ static void *ptr = NULL; \
+  Tau_profile_c_timer(&ptr, name, type, group, #group); \
+  return ptr; \
+} 
+
+#define TAU_GLOBAL_PHASE_START(timer) { void *ptr = TauGlobalPhase##timer(); \
+	Tau_start_timer(ptr, 1); } 
+
+#define TAU_GLOBAL_PHASE_STOP(timer)  { void *ptr = TauGlobalPhase##timer(); \
+	Tau_stop_timer(ptr); }
+
+#define TAU_GLOBAL_PHASE_EXTERNAL(timer)  extern void * TauGlobalPhase##timer(void)
+
+#define TAU_GLOBAL_TIMER(timer, name, type, group) void * TauGlobal##timer(void) \
+{ void *ptr = NULL; \
+  Tau_profile_c_timer(&ptr, name, type, group, #group); \
+  return ptr; \
+} 
+
+
+#define TAU_GLOBAL_TIMER_START(timer) { void *ptr = TauGlobal##timer(); \
+	Tau_start_timer(ptr, 0); }
+
+#define TAU_GLOBAL_TIMER_STOP()  Tau_global_stop()
+
+#define TAU_GLOBAL_TIMER_EXTERNAL(timer)  extern void* TauGlobal##timer(void);
 
 extern void Tau_bcast_data(int data);
 extern void Tau_reduce_data(int data);
@@ -149,7 +181,7 @@ extern void Tau_reducescatter_data(int data);
 extern void Tau_scan_data(int data);
 
 extern void * Tau_get_profiler(char *fname, char *type, TauGroup_t  group, char *gr_name);
-extern void Tau_start_timer(void *profiler);
+extern void Tau_start_timer(void *profiler, int phase);
 extern void Tau_stop_timer(void *profiler);
 extern void Tau_exit(char *msg);
 extern void Tau_init(int argc, char **argv);
@@ -196,6 +228,9 @@ extern void Tau_disable_tracking_memory(void);
 extern void Tau_enable_tracking_muse_events(void);
 extern void Tau_disable_tracking_muse_events(void);
 extern void Tau_set_interrupt_interval(int value);
+extern void Tau_enable_instrumentation(void);
+extern void Tau_disable_instrumentation(void);
+extern void Tau_global_stop(void);
 
 
 
@@ -266,6 +301,21 @@ extern void Tau_set_interrupt_interval(int value);
 
 #define CT(obj)
 
+#define TAU_PHASE_CREATE_STATIC(var, name, type, group) 
+#define TAU_PHASE_CREATE_DYNAMIC(var, name, type, group) 
+#define TAU_PROFILE_TIMER_DYNAMIC(var, name, type, group) 
+#define TAU_PHASE_START(var) 
+#define TAU_PHASE_STOP(var) 
+#define TAU_GLOBAL_PHASE(timer, name, type, group) 
+#define TAU_GLOBAL_PHASE_START(timer) 
+#define TAU_GLOBAL_PHASE_STOP(timer)  
+#define TAU_GLOBAL_PHASE_EXTERNAL(timer) 
+#define TAU_GLOBAL_TIMER(timer, name, type, group)
+#define TAU_GLOBAL_TIMER_EXTERNAL(timer)
+#define TAU_GLOBAL_TIMER_START(timer)
+#define TAU_GLOBAL_TIMER_STOP()
+
+
 #endif /* PROFILING_ON */
 
 #ifdef TRACING_ON
@@ -281,6 +331,7 @@ extern void Tau_set_interrupt_interval(int value);
         Tau_trace_recvmsg(type, source, length);
 #endif /* TRACING_ON */
 
+
 #ifdef TAU_USE_C_API
 }
 #endif /* TAU_USE_C_API */
@@ -290,7 +341,7 @@ extern void Tau_set_interrupt_interval(int value);
 
 /***************************************************************************
  * $RCSfile: TauCAPI.h,v $   $Author: sameer $
- * $Revision: 1.33 $   $Date: 2004/10/30 00:34:08 $
- * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.33 2004/10/30 00:34:08 sameer Exp $
+ * $Revision: 1.38 $   $Date: 2005/01/18 23:57:39 $
+ * POOMA_VERSION_ID: $Id: TauCAPI.h,v 1.38 2005/01/18 23:57:39 sameer Exp $
  ***************************************************************************/
 
