@@ -42,6 +42,8 @@ struct TauJavaLayer {
   static void ThreadStart(JVMPI_Event *event);
   static void ThreadEnd(JVMPI_Event *event);
   static void ShutDown(JVMPI_Event *event);
+  static void DataDump(JVMPI_Event *event);
+  static void DataPurge(JVMPI_Event *event);
   static int *RegisterThread(JVMPI_Event *event);
   static void CreateTopLevelRoutine(char *name, char *type, char *groupname, 
                         int tid);
