@@ -314,8 +314,55 @@ long FunctionInfo::GetFunctionId(void)
 	    
 //////////////////////////////////////////////////////////////////////
 
+
+
+
+
+void tauCreateFI(FunctionInfo **ptr, const char *name, const char *type, 
+		 TauGroup_t ProfileGroup , const char *ProfileGroupName) {
+  if (*ptr == 0) {
+    RtsLayer::LockEnv();
+    if (*ptr == 0) {
+      *ptr = new FunctionInfo(name, type, ProfileGroup, ProfileGroupName);
+    }
+    RtsLayer::UnLockEnv();
+  }
+}
+
+void tauCreateFI(FunctionInfo **ptr, const char *name, const string& type, 
+		 TauGroup_t ProfileGroup , const char *ProfileGroupName) {
+  if (*ptr == 0) {
+    RtsLayer::LockEnv();
+    if (*ptr == 0) {
+      *ptr = new FunctionInfo(name, type, ProfileGroup, ProfileGroupName);
+    }
+    RtsLayer::UnLockEnv();
+  }
+}
+
+void tauCreateFI(FunctionInfo **ptr, const string& name, const char *type, 
+		 TauGroup_t ProfileGroup , const char *ProfileGroupName) {
+  if (*ptr == 0) {
+    RtsLayer::LockEnv();
+    if (*ptr == 0) {
+      *ptr = new FunctionInfo(name, type, ProfileGroup, ProfileGroupName);
+    }
+    RtsLayer::UnLockEnv();
+  }
+}
+
+void tauCreateFI(FunctionInfo **ptr, const string& name, const string& type, 
+		 TauGroup_t ProfileGroup , const char *ProfileGroupName) {
+  if (*ptr == 0) {
+    RtsLayer::LockEnv();
+    if (*ptr == 0) {
+      *ptr = new FunctionInfo(name, type, ProfileGroup, ProfileGroupName);
+    }
+    RtsLayer::UnLockEnv();
+  }
+}
 /***************************************************************************
  * $RCSfile: FunctionInfo.cpp,v $   $Author: amorris $
- * $Revision: 1.35 $   $Date: 2004/09/01 18:52:35 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.cpp,v 1.35 2004/09/01 18:52:35 amorris Exp $ 
+ * $Revision: 1.36 $   $Date: 2005/01/05 21:29:41 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.cpp,v 1.36 2005/01/05 21:29:41 amorris Exp $ 
  ***************************************************************************/
