@@ -169,7 +169,10 @@ char * TauGetCounterString(void)
 
 void Profiler::Start(int tid)
 { 
+      ParentProfiler = CurrentProfiler[tid]; // Timers
+
       x_uint64 TimeStamp = 0L;
+
       DEBUGPROFMSG("Profiler::Start: MyProfileGroup_ = " << MyProfileGroup_ 
         << " Mask = " << RtsLayer::TheProfileMask() <<endl;);
       if ((MyProfileGroup_ & RtsLayer::TheProfileMask()) 
@@ -240,9 +243,6 @@ void Profiler::Start(int tid)
 	DEBUGPROFMSG("Start Time = "<< StartTime<<endl;);
 #endif // PROFILING_ON
   	
-	ParentProfiler = CurrentProfiler[tid] ;
-	  
-
 
 	DEBUGPROFMSG("nct "<< RtsLayer::myNode() << "," 
 	  << RtsLayer::myContext() << ","  << tid 
@@ -282,7 +282,9 @@ Profiler::Profiler( FunctionInfo * function, TauGroup_t ProfileGroup,
       StartStopUsed_ = StartStop; // will need it later in ~Profiler
       MyProfileGroup_ = ProfileGroup ;
       ThisFunction = function ; 
-      ParentProfiler = CurrentProfiler[tid]; // Timers
+#ifdef TAU_PROFILEPHASE
+      SetPhase(false); /* By default it is not in phase */
+#endif /* TAU_PROFILEPHASE */ 
       DEBUGPROFMSG("Profiler::Profiler: MyProfileGroup_ = " << MyProfileGroup_ 
         << " Mask = " << RtsLayer::TheProfileMask() <<endl;);
       
@@ -304,14 +306,20 @@ Profiler::Profiler( const Profiler& X)
 #ifndef TAU_MULTIPLE_COUNTERS	
   StartTime = X.StartTime;
 #else //TAU_MULTIPLE_COUNTERS
+
   for(int i=0;i<MAX_TAU_COUNTERS;i++){
     StartTime[i] = X.StartTime[i];
   }
 #endif//TAU_MULTIPLE_COUNTERS
 
-  DEBUGPROFMSG("Profiler::Profiler(const Profiler& X)"<<endl;);
+#ifdef TAU_PROFILEPHASE
+  PhaseFlag = X.PhaseFlag;
+#endif /* TAU_PROFILEPHASE */ 
 
-	CurrentProfiler[RtsLayer::myThread()] = this;
+
+  DEBUGPROFMSG("Profiler::Profiler(const Profiler& X)"<<endl;);
+  
+  CurrentProfiler[RtsLayer::myThread()] = this;
 
 #if ( defined(PROFILE_CALLS) || defined(PROFILE_STATS) || defined(PROFILE_CALLSTACK) )
 	ExclTimeThisCall = X.ExclTimeThisCall;
@@ -334,6 +342,9 @@ Profiler& Profiler::operator= (const Profiler& X)
 	ParentProfiler = X.ParentProfiler; 
 	MyProfileGroup_ = X.MyProfileGroup_;
  	StartStopUsed_ = X.StartStopUsed_;
+#ifdef TAU_PROFILEPHASE
+        PhaseFlag = X.PhaseFlag;
+#endif /* TAU_PROFILEPHASE */ 
 
 	DEBUGPROFMSG(" Profiler& Profiler::operator= (const Profiler& X)" <<endl;);
 
@@ -2711,11 +2722,24 @@ void Profiler::AddNumChildren(long value)
 }
 #endif /* TAU_COMPENSATE */
 
+#ifdef TAU_PROFILEPHASE
+bool Profiler::GetPhase(void)
+{
+  return PhaseFlag;
+}
+
+void Profiler::SetPhase(bool flag)
+{
+  PhaseFlag = flag;
+}
+
+#endif /* TAU_PROFILEPHASE */
+
 
 /***************************************************************************
  * $RCSfile: Profiler.cpp,v $   $Author: amorris $
- * $Revision: 1.104 $   $Date: 2004/10/04 23:32:15 $
- * POOMA_VERSION_ID: $Id: Profiler.cpp,v 1.104 2004/10/04 23:32:15 amorris Exp $ 
+ * $Revision: 1.107 $   $Date: 2005/01/13 02:32:34 $
+ * POOMA_VERSION_ID: $Id: Profiler.cpp,v 1.107 2005/01/13 02:32:34 amorris Exp $ 
  ***************************************************************************/
 
 	
