@@ -72,7 +72,7 @@ extern "C" void * Tau_get_profiler(char *fname, char *type, TauGroup_t group, ch
 }
 
 ///////////////////////////////////////////////////////////////////////////
-extern "C" void Tau_start_timer(void * function_info)
+extern "C" void Tau_start_timer(void * function_info, int phase)
 {
   FunctionInfo *f = (FunctionInfo *) function_info; 
   TauGroup_t gr = f->GetProfileGroup();
@@ -83,6 +83,12 @@ extern "C" void Tau_start_timer(void * function_info)
 #pragma omp critical
   printf("START tid = %d, profiler= %x\n", RtsLayer::myThread(), p);
 */
+#ifdef TAU_PROFILEPHASE
+  if (phase)
+   p->SetPhase(true);
+  else
+   p->SetPhase(false);
+#endif /* TAU_PROFILEPHASE */
 
     p->Start();
   }
@@ -360,13 +366,15 @@ extern "C" void Tau_trace_sendmsg(int type, int destination, int length)
 #ifdef TAU_EACH_SEND
   TheMsgVolEvent()[destination]->TriggerEvent(length, RtsLayer::myThread());
 #endif /* TAU_EACH_SEND */
-  TAU_TRACE_SENDMSG(type, destination, length);
+  if (destination >= 0)
+    TAU_TRACE_SENDMSG(type, destination, length);
 }
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_trace_recvmsg(int type, int source, int length)
 {
   TAU_EVENT(TheRecvEvent(), length);
-  TAU_TRACE_RECVMSG(type, source, length);
+  if (source >= 0) 
+    TAU_TRACE_RECVMSG(type, source, length);
 }
 
 extern "C" void Tau_bcast_data(int data)
@@ -498,19 +506,25 @@ extern "C" void Tau_profile_c_timer(void **ptr, char *fname, char *type, TauGrou
 #ifdef DEBUG_PROF
   printf("Inside Tau_profile_timer_ fname=%s *ptr = %x\n", fname, *ptr);
 #endif /* DEBUG_PROF */
-  if (*ptr == 0)
-  {  // remove garbage characters from the end of name
-    for(int i=0; i<strlen(fname); i++)
-    {
-      if (!isprint(fname[i]))
-      {
-        fname[i] = '\0';
-        break;
-      }
-    }
-    *ptr = Tau_get_profiler(fname, type, group, group_name);
-  }
 
+
+  if (*ptr == 0) {
+    
+    RtsLayer::LockEnv();
+    
+    if (*ptr == 0) {  
+      // remove garbage characters from the end of name
+      for(int i=0; i<strlen(fname); i++) {
+	if (!isprint(fname[i])) {
+	  fname[i] = '\0';
+	  break;
+	}
+      }
+      *ptr = Tau_get_profiler(fname, type, group, group_name);
+    }
+    RtsLayer::UnLockEnv();
+  }
+  
 #ifdef DEBUG_PROF
   printf("get_profiler returns %x\n", *ptr);
 #endif /* DEBUG_PROF */
@@ -530,7 +544,7 @@ extern "C" void Tau_create_top_level_timer_if_necessary(void)
     ptr = (FunctionInfo *) Tau_get_profiler(".TAU application", " ", TAU_DEFAULT, "TAU_DEFAULT");
     if (ptr)
     {
-      Tau_start_timer(ptr);
+      Tau_start_timer(ptr, 0);
     }
   }
 }
@@ -597,9 +611,16 @@ extern "C" void Tau_set_interrupt_interval(int value)
   TAU_SET_INTERRUPT_INTERVAL(value);
 } 
 
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_global_stop(void)
+{
+  TAU_GLOBAL_TIMER_STOP();
+} 
+
+
 /***************************************************************************
- * $RCSfile: TauCAPI.cpp,v $   $Author: amorris $
- * $Revision: 1.44 $   $Date: 2004/10/04 23:32:15 $
- * VERSION: $Id: TauCAPI.cpp,v 1.44 2004/10/04 23:32:15 amorris Exp $
+ * $RCSfile: TauCAPI.cpp,v $   $Author: sameer $
+ * $Revision: 1.49 $   $Date: 2005/01/19 21:54:17 $
+ * VERSION: $Id: TauCAPI.cpp,v 1.49 2005/01/19 21:54:17 sameer Exp $
  ***************************************************************************/
 
