@@ -40,7 +40,7 @@
 
 extern "C" {
 void * Tau_get_profiler(char *, char *, TauGroup_t, char *gr_name);
-void Tau_start_timer(void *);
+void Tau_start_timer(void * timer, int phase);
 void Tau_stop_timer(void *);
 void Tau_exit(char *);
 void Tau_init(int, char **);
@@ -177,6 +177,22 @@ void tau_profile_timer_(void **ptr, char *infname, int slen)
   return;
 }
 
+void tau_phase_create_static_(void **ptr, char *infname, int slen)
+{
+  tau_profile_timer_(ptr, infname, slen);
+}
+
+void tau_phase_create_dynamic_(void **ptr, char *infname, int slen)
+{
+  *ptr = 0;  /* reset it each time so it creates a new timer */
+  tau_profile_timer_(ptr, infname, slen);
+}
+
+void tau_profile_timer_dynamic_(void **ptr, char *infname, int slen)
+{ /* This routine is identical to tau_phase_create_dynamic */
+  *ptr = 0;  /* reset it each time so it creates a new timer */
+  tau_profile_timer_(ptr, infname, slen);
+}
 
 void tau_profile_start_(void **profiler)
 { 
@@ -184,7 +200,7 @@ void tau_profile_start_(void **profiler)
   printf("start_timer gets %lx\n", *profiler);
 #endif /* DEBUG_PROF */
 
-  Tau_start_timer(*profiler);
+  Tau_start_timer(*profiler, 0);
   return;
 }
 
@@ -194,6 +210,18 @@ void tau_profile_stop_(void **profiler)
   return;
 }
 
+void tau_phase_start_(void **profiler)
+{
+  Tau_start_timer(*profiler, 1); /* 1 indicates phase based profiling */
+  return;
+}
+
+void tau_phase_stop_(void **profiler)
+{
+  Tau_stop_timer(*profiler);
+  return;
+}
+
 void tau_profile_exit_(char *msg)
 {
   Tau_exit(msg);
@@ -737,7 +765,7 @@ void TAU_SET_INTERRUPT_INTERVAL(int* value)
 
 void tau_profile_start(int **profiler)
 {
-  Tau_start_timer((void *)*profiler);
+  Tau_start_timer((void *)*profiler, 0);
 }
 
 void tau_profile_stop(int **profiler)
@@ -825,7 +853,7 @@ void tau_event(int **ptr, double *data)
 //#endif /* TAU_XLC || TAU_AIX || HP_FORTRAN */
 
 
-#ifdef TAU_GNU
+#if (defined (TAU_GNU) || defined (TAU_PATHSCALE))
 
 void tau_profile_timer__(void **ptr, char *fname, int flen)
 {
@@ -1044,12 +1072,91 @@ void tau_set_interrupt_interval__(int* value)
   Tau_set_interrupt_interval(*value);
 } 
 
+void tau_phase_create_static__(void **ptr, char *infname, int slen)
+{
+  tau_phase_create_static_(ptr, infname, slen);
+}
+
+void tau_phase_create_dynamic__(void **ptr, char *infname, int slen)
+{
+  tau_phase_create_dynamic_(ptr, infname, slen);
+}
+
+void tau_profile_timer_dynamic__(void **ptr, char *infname, int slen)
+{
+  tau_profile_timer_dynamic_(ptr, infname, slen);
+}
+
+void tau_phase_start__(void **profiler)
+{
+  tau_phase_start_(profiler);
+}
+
+void tau_phase_stop__(void **profiler)
+{
+  tau_phase_stop_(profiler);
+}
+
+#endif /* TAU_GNU || TAU_PATHSCALE */
+//////////////////////////////////////////////////////
+// PHASE BASED PROFILING
+//////////////////////////////////////////////////////
+
+void tau_phase_create_static(void **ptr, char *infname, int slen)
+{
+  tau_phase_create_static_(ptr, infname, slen);
+}
+
+void tau_phase_create_dynamic(void **ptr, char *infname, int slen)
+{
+  tau_phase_create_dynamic_(ptr, infname, slen);
+}
+
+void tau_profile_timer_dynamic(void **ptr, char *infname, int slen)
+{
+  tau_profile_timer_dynamic_(ptr, infname, slen);
+}
+
+void tau_phase_start(void **profiler)
+{
+  tau_phase_start_(profiler);
+}
+
+void tau_phase_stop(void **profiler)
+{
+  tau_phase_stop_(profiler);
+}
+
+void TAU_PHASE_CREATE_STATIC(void **ptr, char *infname, int slen)
+{
+  tau_phase_create_static_(ptr, infname, slen);
+}
+
+void TAU_PHASE_CREATE_DYNAMIC(void **ptr, char *infname, int slen)
+{
+  tau_phase_create_dynamic_(ptr, infname, slen);
+}
+
+void TAU_PROFILE_TIMER_DYNAMIC(void **ptr, char *infname, int slen)
+{
+  tau_profile_timer_dynamic_(ptr, infname, slen);
+}
+
+void TAU_PHASE_START(void **profiler)
+{
+  tau_phase_start_(profiler);
+}
+
+void TAU_PHASE_STOP(void **profiler)
+{
+  tau_phase_stop_(profiler);
+}
+
 
-#endif /* TAU_GNU */
 } /* extern "C" */
 
 /***************************************************************************
  * $RCSfile: TauFAPI.cpp,v $   $Author: sameer $
- * $Revision: 1.34 $   $Date: 2004/10/20 17:31:39 $
- * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.34 2004/10/20 17:31:39 sameer Exp $ 
+ * $Revision: 1.39 $   $Date: 2005/01/18 23:58:20 $
+ * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.39 2005/01/18 23:58:20 sameer Exp $ 
  ***************************************************************************/
