@@ -37,7 +37,7 @@ Ttf_FileHandleT Ttf_OpenFileForInput( const char *filename, const char *EDF)
   }
 
   /* Open the trace file */
-  if ( (tFile->Fid = open (filename, O_RDONLY)) < 0 )
+  if ( (tFile->Fid = open (filename, O_RDONLY | O_BINARY)) < 0 )
   {
     perror (filename);
     return NULL;
@@ -45,7 +45,7 @@ Ttf_FileHandleT Ttf_OpenFileForInput( const char *filename, const char *EDF)
 
   /* Open the EDF (event description file) to read the <name, id> event 
    * tables*/
-  if ((fp = fopen (EDF, "r")) == NULL)
+  if ((fp = fopen (EDF, "rb")) == NULL)
   {
     printf("EDF file = %s\n", EDF);
     perror("ERROR: opening edf file");
@@ -331,6 +331,12 @@ int Ttf_ReadNumEvents( Ttf_FileHandleT fileHandle, Ttf_CallbacksT callbacks,
     } /* entry exit events *//* add message passing events here */
     else 
     {
+      if ((eventDescr.Param != NULL) && (strcmp(eventDescr.Param,"TriggerValue\n")==0))
+      { /* User defined event */
+	 if (*callbacks.EventTrigger)
+	   (*callbacks.EventTrigger)(callbacks.UserData, ts, nid, tid, 
+				     traceBuffer[i].ev, traceBuffer[i].par);
+      }
       if (eventDescr.Tag == TAU_MESSAGE_SEND_EVENT) 
       {
         /* send message */
@@ -452,7 +458,7 @@ int refreshTables(Ttf_fileT *tFile, Ttf_CallbacksT cb)
   dynamictrace = FALSE;
  
   /* first, open the edf file */
-  if ((edf = fopen (tFile->EdfFile, "r")) == NULL )
+  if ((edf = fopen (tFile->EdfFile, "rb")) == NULL )
   {
     printf("ERROR: opening edf file %s\n", tFile->EdfFile);
     perror (tFile->EdfFile);
@@ -525,17 +531,29 @@ int refreshTables(Ttf_fileT *tFile, Ttf_CallbacksT cb)
 	  groupid = tFile->GroupIdMap->size()+1;
 	  (*(tFile->GroupIdMap))[eventDescr->Group] = groupid;
 	  /* invoke group callback */
-	  if (*cb.DefStateGroup)
-	    (*cb.DefStateGroup)(cb.UserData, groupid, eventDescr->Group); 
+	  /* check Param to see if its a user defined event */
+	  if (strcmp(eventDescr->Param, "TriggerValue") != 0)
+	  { /* it is not a user defined event */
+	    if (*cb.DefStateGroup)
+	      (*cb.DefStateGroup)(cb.UserData, groupid, eventDescr->Group); 
+	  }
 	}
 	else
 	{ /* retrieve the stored group id token */
 	  groupid = (*git).second;
 	}
         /* invoke callback for registering a new state */
-	if (*cb.DefState)
-	  (*cb.DefState)(cb.UserData, localEventId, eventDescr->EventName, 
+	if (strcmp(eventDescr->Param, "TriggerValue\n") == 0)
+        { /* it is a user defined event */
+          if (*cb.DefUserEvent)
+	    (*cb.DefUserEvent)(cb.UserData, localEventId, eventDescr->EventName, eventDescr->Tag);
+	}
+	else
+        { /* it is not a user defined event */
+	  if (*cb.DefState)
+	    (*cb.DefState)(cb.UserData, localEventId, eventDescr->EventName, 
 		      groupid);
+	}
 	
       }
       /* else, do nothing, examine the next record */
@@ -558,7 +576,7 @@ int refreshTables(Ttf_fileT *tFile, Ttf_CallbacksT cb)
   return TRUE;
 }
 /***************************************************************************
- * $RCSfile: TAU_tf.cpp,v $   $Author: sameer $
- * $Revision: 1.2 $   $Date: 2003/12/05 23:50:40 $
- * TAU_VERSION_ID: $Id: TAU_tf.cpp,v 1.2 2003/12/05 23:50:40 sameer Exp $ 
+ * $RCSfile: TAU_tf.cpp,v $   $Author: amorris $
+ * $Revision: 1.5 $   $Date: 2004/09/01 18:53:28 $
+ * TAU_VERSION_ID: $Id: TAU_tf.cpp,v 1.5 2004/09/01 18:53:28 amorris Exp $ 
  ***************************************************************************/
