@@ -13,7 +13,7 @@ public interface DB {
     ResultSet executeQuery(String statement) throws SQLException;
     int executeUpdate(String statement) throws SQLException;
     boolean execute(String statement) throws SQLException;
-    String getDataItem(String query);
+    String getDataItem(String query) throws SQLException;
     public boolean isClosed();
     public String getDBType();
     public Connection getConnection();
@@ -23,4 +23,9 @@ public interface DB {
 
     public int checkSchema() throws SQLException;
 
+
+    public void setAutoCommit(boolean auto) throws SQLException;
+    public void commit() throws SQLException;
+    public void rollback() throws SQLException;
+
 }
