@@ -2,11 +2,6 @@ package edu.uoregon.tau.dms.loader;
 
 import edu.uoregon.tau.dms.database.*;
 import jargs.gnu.CmdLineParser;
-import java.io.BufferedReader;
-import java.io.File;
-import java.io.InputStreamReader;
-import java.net.InetAddress;
-import java.sql.SQLException;
 
 public class LoadSchema {
     private Load load = null;
