@@ -15,21 +15,14 @@ public interface DisplayProperties{
     public void setUnits(int units);
     public int getUnits();
 
-    //####################################
-    //Instance data.
-    //####################################
     public static final int EXCLUSIVE = 2;
     public static final int INCLUSIVE = 4;
     public static final int NUMBER_OF_CALLS = 6;
     public static final int NUMBER_OF_SUBROUTINES = 8;
-    public static final int PAR_CALL_VALUE = 10;
+    public static final int INCLUSIVE_PER_CALL = 10;
     public static final int DESCENDING_ORDER = 0;
     public static final int ASCENDING_ORDER = 1;
     public static final int MICROSECONDS = 0;
     public static final int MILLISECONDS = 1;
     public static final int SECONDS = 2;
-    //####################################
-    //End - Instance data.
-    //####################################
-
 }
