@@ -8,12 +8,14 @@ declare -i group_f_F=1
 declare -i group_c=2
 declare -i group_C=3
 
+declare -i disablePdtStep=$FALSE
 declare -i hasAnOutputFile=$FALSE
 declare -i fortranParserDefined=$FALSE
 declare -i isForCompilation=$FALSE
 declare -i hasAnObjectOutputFile=$FALSE
 declare -i hasMpi=$TRUE
 declare -i needToCleanPdbInstFiles=$TRUE
+declare -i pdbFileSpecified=$FALSE
 
 declare -i isVerbose=$FALSE
 declare -i isDebug=$FALSE
@@ -45,6 +47,7 @@ printUsage () {
 	echo -e "  -optPdtUser=\"\"\t\tOptional arguments for parsing source code"
 	echo -e "  -optTauInstr=\"\"\t\tSpecify location of tau_instrumentor. Typically \$(TAUROOT)/\$(CONFIG_ARCH)/bin/tau_instrumentor"
 	echo -e "  -optTauSelectFile=\"\"\t\tSpecify selective instrumentation file for tau_instrumentor"
+	echo -e "  -optPDBFile=\"\"\t\tSpecify PDB file for tau_instrumentor. Skips parsing stage."
 	echo -e "  -optTau=\"\"\t\t\tSpecify options for tau_instrumentor"
 	echo -e "  -optCompile=\"\"\t\tOptions passed to the compiler. Typically \$(TAU_MPI_INCLUDE) \$(TAU_INCLUDE) \$(TAU_DEFS)"
 	echo -e "  -optReset=\"\"\t\t\tReset options to the compiler to the given list"
@@ -169,6 +172,10 @@ for arg in "$@"
 			-optPdtDir*)
 				optPdtDir=${arg#"-optPdtDir="}"/bin"
 				echoIfDebug "\tpdtDir read is: $optPdtDir"
+				if [ ! -d $optPdtDir ]; then
+				  disablePdtStep=$TRUE
+				  echoIfDebug "PDT is not configured."
+				fi 
 				;;
 
 			-optPdtF95Opts*)
@@ -248,6 +255,11 @@ for arg in "$@"
 				optCompile=${arg#"-optReset="}
 				echoIfDebug "\tCompiling Options are: $optCompile"
 				;;
+			-optPDBFile*)
+				optPDBFile="${arg#"-optPDBFile="}"
+				pdbFileSpecified=$TRUE
+				echoIfDebug "\tPDB File used: $optPDBFile"
+				;;
 
 			-optPdtCReset*)
 				optPdtCFlags=${arg#"-optPdtCReset="}
@@ -327,6 +339,17 @@ for arg in "$@"
 			argsRemaining="$argsRemaining $arg"
 			;;
 
+		-M*|-S|-E)
+# We ignore -M processing step for making dependencies, -S for assembly
+# and -E for preprocessing the source code. These are the options that are 
+# ignored by PDT. Add to this list if you need an additional option that should
+# be ignored by the PDT step. 
+#			echoIfDebug "tau_compiler.sh> Ignoring -M* compilation step for making dependencies"
+			disablePdtStep=$TRUE
+			gotoNextStep=$FALSE
+			errorStatus=$TRUE
+			;;
+
 
 		*.o)
 			objectOutputFile="$arg"
@@ -392,7 +415,11 @@ while [ $tempCounter -lt $numFiles ]; do
 	newFile=${base}.inst${suf}
 	arrTau[$tempCounter]="${OUTPUTARGSFORTAU}${newFile}"
 	arrPdbForTau[$tempCounter]="${PDBARGSFORTAU}${newFile}"
-	newFile=${base}.pdb
+	if [ $pdbFileSpecified == $FALSE ]; then
+	  newFile=${base}.pdb
+	else
+	  newFile=$optPDBFile; 
+	fi
 	arrPdb[$tempCounter]="${PDBARGSFORTAU}${newFile}"
 	tempCounter=tempCounter+1
 done
@@ -478,14 +505,23 @@ if [ $gotoNextStep == $TRUE ]; then
 
 		esac
 
-		evalWithDebugMessage "$pdtCmd" "Parsing with PDT Parser"
-		#Assumption: The pdb file would be formed int eh current directory, so need 
+		if [ $disablePdtStep == $FALSE ]; then
+		  if [ $pdbFileSpecified == $FALSE ]; then
+		    evalWithDebugMessage "$pdtCmd" "Parsing with PDT Parser"
+		  fi
+		else
+		  echo "tau_compiler.sh> WARNING: Disabling instrumentation of source code. TAU was not configured with -pdt=<dir> option."
+		  gotoNextStep=$FALSE
+		  errorStatus=$TRUE
+		fi
+
+		#Assumption: The pdb file would be formed in the current directory, so need 
 		#to strip  the fileName from the directory. Since sometime,
 		#you can be creating a pdb in the current directory using
 		#a source file located in another directory.
 		tempFileName=${arrPdb[$tempCounter]##*/}
 		echoIfDebug "Looking for pdb file $tempFileName "
-		if [  ! -e $tempFileName ]; then
+		if [  ! -e $tempFileName  -a $disablePdtStep == $FALSE ]; then
 			echoIfVerbose "Error: Tried Looking for file: $tempFileName"
 			printError "$PDTPARSER" "$pdtCmd"
 			break
@@ -509,7 +545,11 @@ if [ $gotoNextStep == $TRUE ]; then
 		tempInstFileName=${arrTau[$tempCounter]##*/}
 		tauCmd="$optTauInstr $tempPdbFileName ${arrFileName[$tempCounter]} -o $tempInstFileName "
 		tauCmd="$tauCmd $optTau $optTauSelectFile"
-		evalWithDebugMessage "$tauCmd" "Instrumenting with TAU"
+		if [ $disablePdtStep == $FALSE ]; then
+		  evalWithDebugMessage "$tauCmd" "Instrumenting with TAU"
+		else
+		  echoIfDebug "Not instrumenting source code. PDT not available."
+		fi
 
 		echoIfDebug "Looking for tau file $tempInstFileName"
 		if [  ! -e $tempInstFileName ]; then
@@ -552,8 +592,7 @@ if [ $gotoNextStep == $TRUE ]; then
 
 			tempTauFileName=${arrTau[$tempCounter]##*/}
 			instrumentedFileForCompilation="$tempTauFileName"
-			newCmd="$CMD  $instrumentedFileForCompilation  $OUTPUTARGSFORTAU "
-			newCmd="$newCmd $optCompile $argsRemaining"
+			newCmd="$CMD  $argsRemaining $instrumentedFileForCompilation  $OUTPUTARGSFORTAU $optCompile"
 
 			#echoIfDebug "cmd before appending the .o file is $newCmd"
 			if [ $hasAnOutputFile == $TRUE ]; then
@@ -598,8 +637,7 @@ if [ $gotoNextStep == $TRUE ]; then
 			tempTauFileName=${arrTau[$tempCounter]##*/}
 			instrumentedFileForCompilation=" $tempTauFileName"
 
-			newCmd="$CMD  -c $instrumentedFileForCompilation  $OUTPUTARGSFORTAU "
-			newCmd="$newCmd $optCompile $argsRemaining -o $outputFile"
+			newCmd="$CMD $argsRemaining  -c $instrumentedFileForCompilation  $OUTPUTARGSFORTAU $optCompile -o $outputFile"
 
 			evalWithDebugMessage "$newCmd" "Compiling (Individually) with Instrumented Code"
 			if [  ! -e $outputFile ]; then
@@ -616,8 +654,7 @@ if [ $gotoNextStep == $TRUE ]; then
 			passedOutputFile="a.out"
 		fi
 
-		newCmd="$CMD  $listOfObjectFiles $objectFilesForLinking $OUTPUTARGSFORTAU "
-		newCmd="$newCmd $optLinking $argsRemaining -o $passedOutputFile"
+		newCmd="$CMD  $argsRemaining $listOfObjectFiles $objectFilesForLinking $OUTPUTARGSFORTAU $optLinking -o $passedOutputFile"
 		evalWithDebugMessage "$newCmd" "Linking (Together) object files"
 
 		if [ ! -e $passedOutputFile ] ; then
@@ -630,9 +667,11 @@ fi
 
 if [ $needToCleanPdbInstFiles == $TRUE ]; then
 	tempCounter=0
-	while [ $tempCounter -lt $numFiles ]; do
+	while [ $tempCounter -lt $numFiles -a $disablePdtStep == $FALSE ]; do
 		eval "rm ${arrTau[$tempCounter]##*/}"
-		eval "rm ${arrPdb[$tempCounter]##*/}"
+		if [ $pdbFileSpecified == $FALSE ]; then
+		  eval "rm ${arrPdb[$tempCounter]##*/}"
+		fi
 		tempCounter=tempCounter+1
 	done
 fi
