@@ -18,7 +18,6 @@
 # include <stdlib.h>
 # include <sys/types.h>
 # include <fcntl.h>
-# include <unistd.h>
 
 #ifdef TAU_NEC
 extern "C" {
@@ -27,7 +26,14 @@ int getdtablesize(void);
 #endif /* TAU_NEC */
 
 #ifndef NeXT
-# include <unistd.h>
+  #ifdef TAU_WINDOWS
+    #include <windows.h>	
+    #include <io.h>
+    #include "getopt.h"
+  #else
+    #define O_BINARY 0
+    #include <unistd.h>
+  #endif
 #endif
 
 #ifdef FUJITSU
@@ -63,10 +69,11 @@ int getdtablesize(void);
 
 int dynamic = TRUE ; /* by default events.<node>.edf files exist */
 int dontblock = FALSE; /* by default, block waiting for records, online merge*/
+char *mergededffile = NULL; /* default merged EDF file name */
 #if !(defined(TAU_XLC) || defined (TAU_NEC))
 extern "C" {
 #endif /* TAU_XLC || TAU_NEC */
-  int open_edf_file(char *prefix, int nodeid);
+  int open_edf_file(char *prefix, int nodeid, int prefix_is_filename);
   int parse_edf_file(int node);
   int store_merged_edffile(char *filename);
   const char *get_event_name(int gid);
@@ -76,7 +83,7 @@ extern "C" {
 #endif /* TAU_XLC || TAU_NEC */
 
 
-static struct trcdescr
+struct trcdescr
 {
   int     fd;              /* -- input file descriptor                     -- */
   char   *name;            /* -- corresponding file name                   -- */
@@ -143,7 +150,7 @@ static PCXX_EV *get_next_rec(struct trcdescr *tdes)
 #ifdef DEBUG
 	      printf("Blocking...");
 #endif /* DEBUG */
-	      store_merged_edffile("tau.edf");
+	      store_merged_edffile(mergededffile);
 	      output_flush(outfd);
 	      /* Block waiting for the trace to get some more records in it */
 	      while ((no = read (tdes->fd, tdes->buffer, INMAX * sizeof(PCXX_EV))) == 0)
@@ -151,7 +158,11 @@ static PCXX_EV *get_next_rec(struct trcdescr *tdes)
 #ifdef DEBUG
 		printf("WAITING... no = %d, node filename = %s \n", no, tdes->name);
 #endif /* DEBUG */
-		sleep(1);
+		#ifdef TAU_WINDOWS
+		 Sleep(1);
+		#else
+  	 	 sleep(1);
+		#endif
 	      }
 	      /* got the trace data! */
 #ifdef DEBUG
@@ -238,11 +249,18 @@ static void output(int fd, char *data, size_t l)
 /* -- FILE DESCRIPTOR HANDLING ---------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-#include <sys/time.h>
-#include <sys/resource.h>
+#ifndef TAU_WINDOWS
+  #include <sys/time.h>
+  #include <sys/resource.h>
+#endif
+
+
 
 int cannot_get_enough_fd(int need)
 {
+#ifdef TAU_WINDOWS
+  return false; // no getdtablesize() in windows
+#else	
 # if defined(__hpux) || defined(sun)
   /* -- system supports get/setrlimit (RLIMIT_NOFILE) -- */
   struct rlimit rlp;
@@ -267,19 +285,24 @@ int cannot_get_enough_fd(int need)
       return ( max < need );
 #   endif
 # endif
+#endif /* TAU_WINDOWS */
 }
 
+
 /* -------------------------------------------------------------------------- */
 /* -- PCXX_MERGE MAIN PROGRAM ----------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
 extern char *optarg;
 extern int   optind;
+char **edfnames; /* if they're specified */
+int edfspecified; /* tau_events also needs this */
 
 int main(int argc, char *argv[])
 {
   int i, active, numtrc, source, errflag, first;
-  int adjust, min_over, reassembly;
+  int adjust, min_over, reassembly, numedfprocessed;
+  int startedfindex, edfcount;
   unsigned long min_time, first_time;
   long numrec;
   char *trcfile;
@@ -292,15 +315,19 @@ int main(int argc, char *argv[])
   unsigned long last_time;
 # endif
 
+  edfcount   = 0;
   numtrc     = 0;
   numrec     = 0;
   errflag    = FALSE;
   dontblock  = FALSE; /* by default, block */
   adjust     = FALSE;
   reassembly = TRUE;
+  edfspecified = FALSE; /* by default edf files are not specified on cmdline */
+  numedfprocessed = 0 ; /* only used with -e events.*.edf files are specified */
   first_time = 0L;
+  mergededffile = strdup("tau.edf"); /* initialize it */
 
-  while ( (i = getopt (argc, argv, "arn")) != EOF )
+  while ( (i = getopt (argc, argv, "arne:m:")) != EOF )
   {
     switch ( i )
     {
@@ -312,15 +339,57 @@ int main(int argc, char *argv[])
                 reassembly = FALSE;
                 break;
 
-      default : /* -- ERROR -- */
-                errflag = TRUE;
+      case 'e': /* -- EDF files specified on the commandline -- */
+                edfspecified = TRUE;
+		numedfprocessed = 0;
+		edfnames = (char **) malloc (argc * (sizeof(char *))); 
+		/* first array */
+		for (i = optind-1; i < argc; i++)
+		{
+		  if(strstr(argv[i], ".edf") != 0)
+		  {
+#ifdef DEBUG
+		    printf("Processing Event file %s for node %d\n", argv[i],
+				    numedfprocessed);
+#endif /* DEBUG */
+	            open_edf_file(argv[i], numedfprocessed, TRUE);
+		    numedfprocessed++; 
+		    /* store the name of the edf file so that we can re-open 
+		     * it later if event files need to be re-read */
+		    edfnames[edfcount] = strdup(argv[i]);
+		    edfcount++; /* increment the count */
+		  }
+		  else 
+		    break; /* come out of the loop! */
+		}
+		optind += numedfprocessed - 1; 
+#ifdef DEBUG
+		printf("numedfprocessed = %d, optind = %d, argc = %d, argv[optind] = %s\n",
+				numedfprocessed, optind, argc, argv[optind]);
+#endif /* DEBUG */
                 break;
+
+      case 'm': /* -- name of the merged edf file (instead of tau.edf) */
+		mergededffile = strdup(argv[optind-1]);
+#ifdef DEBUG
+		printf("merged edf file = %s\n", mergededffile);
+#endif /* DEBUG */
+		break;
+
       case 'n': /* -- do not block for records at end of trace -- */
 		dontblock = TRUE; 
 		break;
+
+      default : /* -- ERROR -- */
+                errflag = TRUE;
+                break;
+
     }
   }
 
+#ifdef DEBUG
+  printf("optind = %d, argc = %d\n", optind, argc);
+#endif /* DEBUG */
   /* -- check whether enough file descriptors available: -------------------- */
   /* -- max-file-descriptors - 4 (stdin, stdout, stderr, output trace) ------ */
   active = argc - optind - 1;
@@ -336,7 +405,7 @@ int main(int argc, char *argv[])
   for (i=optind; i<argc-1; i++)
   {
     /* -- open input trace -------------------------------------------------- */
-    if ( (trcdes[numtrc].fd = open (argv[i], O_RDONLY)) < 0 )
+    if ( (trcdes[numtrc].fd = open (argv[i], O_RDONLY | O_BINARY)) < 0 )
     {
       perror (argv[i]);
       errflag = TRUE;
@@ -360,12 +429,14 @@ int main(int argc, char *argv[])
         active--;
       }
 
+      /* We can't do this check because the event is EV_INIT, but its ev id
+       * is different from original creation time after merging */
       /* -- check first event record ---------------------------------------- */
-      else if ( (erec->ev != PCXX_EV_INIT) && (erec->ev != PCXX_EV_INITM) )
+      /* else if ( (erec->ev != PCXX_EV_INIT) && (erec->ev != PCXX_EV_INITM) )
       {
         fprintf (stderr, "%s: no valid event trace\n", trcdes[numtrc].name);
         exit (1);
-      }
+      } */
       else
       {
         if ( erec->nid > PCXX_MAXPROCS )
@@ -390,8 +461,13 @@ int main(int argc, char *argv[])
 	if(dynamic)
 	{
 	/* parse edf file for this trace */
-	  open_edf_file("events", trcdes[numtrc].nid);
-	  parse_edf_file(trcdes[numtrc].nid);
+	  if (edfspecified == FALSE)
+	  { /* use default edf file names  "events.*.edf" */
+	    char eventfilename[2048];
+	    sprintf(eventfilename, "events.%d.edf", trcdes[numtrc].nid); 
+	    open_edf_file(eventfilename, numtrc, TRUE);
+	  }
+	  parse_edf_file(numtrc);
 	}
         numtrc++;
       }
@@ -400,19 +476,24 @@ int main(int argc, char *argv[])
   if (dynamic)
   {
     /* all edf files have been parsed now - store the final edf merged file */
-    store_merged_edffile("tau.edf");
+    store_merged_edffile(mergededffile);
   }
 
   if ( (numtrc < 1) || errflag )
   {
     fprintf (stderr,
-             "usage: %s [-a] [-r] [-n] inputtraces* (outputtrace|-)\n", argv[0]);
+             "usage: %s [-a] [-r] [-n] inputtraces* (outputtrace|-) [-e eventedf* ] [-m mergededf]\n", argv[0]);
     fprintf(stderr,
     "Note: %s assumes edf files are named events.<nodeid>.edf and \n", argv[0]);
     fprintf(stderr,"      generates a merged edf file tau.edf\n");
     fprintf(stderr,"-a : adjust first time to zero\n");
     fprintf(stderr,"-r : do not reassemble long events\n");
     fprintf(stderr,"-n : do not block waiting for new events. Offline merge\n");
+    fprintf(stderr,"-e <files> : provide a list of event definition files corresponding to traces\n");
+    fprintf(stderr,"-m <mergededf> : specify the name of the merged event definition file\n");
+    fprintf(stderr,"e.g., % %s tautrace.*.trc app.trc\n", argv[0]);
+    fprintf(stderr,"e.g., % %s tautrace.[0-255].*.trc events.[0-255].edf app.trc -m ev0_255merged.edf\n", argv[0]);
+
 
 
     exit (1);
@@ -436,7 +517,7 @@ int main(int argc, char *argv[])
       fprintf (stderr, "%s exists; override [y]? ", trcfile);
       if ( getchar() == 'n' ) exit (1);
     }
-    if ( (outfd = open (trcfile, O_WRONLY|O_CREAT|O_TRUNC, 0644)) < 0 )
+    if ( (outfd = open (trcfile, O_WRONLY|O_CREAT|O_TRUNC|O_BINARY, 0644)) < 0 )
     {
       perror (trcfile);
       exit (1);
@@ -521,7 +602,7 @@ int main(int argc, char *argv[])
     /* -- if file was closed during the search for barriers, re-open it ----- */
     if ( trcdes[i].fd = -1 )
     {
-      if ( (trcdes[i].fd = open (trcdes[i].name, O_RDONLY)) < 0 )
+      if ( (trcdes[i].fd = open (trcdes[i].name, O_RDONLY|O_BINARY)) < 0 )
       {
         perror (argv[i]);
         exit (1);
@@ -656,7 +737,9 @@ int main(int argc, char *argv[])
     printf("Before conv event %ld ", trcdes[source].erec->ev);
 #endif /* DEBUG */
 
-    trcdes[source].erec->ev = GID(trcdes[source].nid, trcdes[source].erec->ev);
+    /* OLD : trcdes[source].erec->ev = GID(trcdes[source].nid, trcdes[source].erec->ev);
+     */
+    trcdes[source].erec->ev = GID(source, trcdes[source].erec->ev);
 
 #ifdef DEBUG
     printf("Output: node %d event %d\n", source, trcdes[source].erec->ev);
@@ -692,7 +775,9 @@ int main(int argc, char *argv[])
         {
           /* -- continuation event: output immediately ---------------------- */
 	  /* -- dynamic traces, correct event id to global event id --------- */
-	  erec->ev = GID(trcdes[source].nid, erec->ev);
+	  /* OLD: erec->ev = GID(trcdes[source].nid, erec->ev);
+	   * */
+	  erec->ev = GID(source, erec->ev);
           if ( reassembly )
           {
             output (outfd, ((char *) erec) + sizeof(short unsigned int),
